OC.L10N.register(
    "news",
    {
    "Saved" : "সংরক্ষণ করা হলো",
    "Download" : "ডাউনলোড",
    "Close" : "বন্ধ",
    "by" : "কর্তৃক",
    "from" : "হইতে",
    "Description" : "বিবরণ",
    "right" : "ডান",
    "left" : "বাম",
    "Refresh" : "নবোদ্যম",
    "Subscribe" : "গ্রাহক হোন",
    "Web address" : "ওয়েব ঠিকানা",
    "Feed exists already!" : "ফিড পূর্বে থেকেই বিদ্যমান",
    "Folder" : "ফোল্ডার",
    "New folder" : "নব ফােলডার",
    "Folder name" : "ফোলডারের নাম",
    "Go back" : "ফিরে যাও",
    "Folder exists already!" : "ফোল্ডার ইতোমধ্যে বিদ্যমান!",
    "Credentials" : "Credentials",
    "Username" : "ব্যবহারকারী",
    "Password" : "কূটশব্দ",
    "New Folder" : "নতুন ফোল্ডার",
    "Create" : "তৈরী কর",
    "Deleted feed" : "মুছে ফেলা ফিড",
    "Rename" : "পূনঃনামকরণ",
    "Delete" : "মুছে",
    "Collapse" : "ভাঙো",
    "Starred" : "তারা চিহ্নিত",
    "Unread articles" : "অপঠিত লেখা",
    "All articles" : "সব লেখা",
    "Settings" : "নিয়ামকসমূহ",
    "Subscriptions (OPML)" : "সাবস্ক্রিপশন (OPML)",
    "Import" : "আমদানি",
    "Export" : "রপ্তানি",
    "Unread/Starred Articles" : "অপঠিত/তারকাচিহ্নিত লেখা",
    "Error when importing: file does not contain valid JSON" : "আমদানীজণিত সমস্যা: ফাইলের JSON সঠিক নয়",
    "Help" : "সহায়িকা",
    "Keyboard shortcuts" : "কী-বোর্ড শর্টকাট",
    "Documentation" : "নথিবদ্ধকরণ"
},
"nplurals=2; plural=(n != 1);");
